import { RouterModule } from '@angular/router';
import { Component, OnInit } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FontAwesomeModule } from '@fortawesome/angular-fontawesome';
import { 
  faBrain, 
  faBell, 
  faUser, 
  faArrowRight, 
  faRobot, 
  faComments, 
  faDatabase, 
  faUserTie, 
  faTimes, 
  faHistory, 
  faStar, 
  faChartLine, 
  faFileAlt, 
  faBullhorn 
} from '@fortawesome/free-solid-svg-icons';
@Component({
  imports: [RouterModule,CommonModule],
  templateUrl: './page-crm-home.html',
  styleUrl: './page-crm-home.scss',
  selector: 'page-crm-home', // 确保选择器匹配HTML中的使用
  standalone: true,
})


export class PageCrmHome implements OnInit {
  // Font Awesome 图标
  icons = {
    faBrain, faBell, faUser, faArrowRight, faRobot, faComments, 
    faDatabase, faUserTie, faTimes, faHistory, faStar, 
    faChartLine, faFileAlt, faBullhorn
  };

  // 状态变量
  showMessagePopup: boolean = false;
  showProfilePopup: boolean = false;
  unreadMessagesCount: number = 3;

  // 数据
  motivationalText: string = '每一次对话都是展现专业的机会，每一次练习都在提升成功的概率！今天，让AI成为您最强大的销售伙伴';
  stats = {
    practiceCount: 42,
    strategyCount: 28,
    satisfactionRate: 96
  };
  
  features = {
    virtualPractice: { count: 12, score: 85 },
    speechStrategy: { count: 8, effectiveness: 92 },
    dataTraining: { size: '3.2TB', accuracy: 98 },
    customerProfile: { count: 24 }
  };
  
  userStats = {
    practiceCount: 12,
    beatPercentage: 86
  };
  
  user = {
    name: '张明',
    role: '高级销售经理'
  };
  
  messages = [
    { title: '新的陪练挑战', preview: '您有一个新的虚拟陪练挑战等待完成，主题：高端客户价格谈判', time: '10分钟前', unread: true },
    { title: '话术策略更新', preview: '您收藏的"投诉处理"话术策略已更新至3.2版本', time: '1小时前', unread: true },
    { title: '陪练成绩通知', preview: '您最近的虚拟陪练成绩为92分，超过89%的销售同事', time: '昨天', unread: false },
    { title: '团队周报', preview: '本周团队陪练报告已生成，点击查看详细分析', time: '2天前', unread: false },
    { title: '系统维护通知', preview: '系统将于本周六凌晨2:00-4:00进行维护升级', time: '3天前', unread: false }
  ];
  
  trainings = [
    { title: '高端客户价格谈判', date: '2023-10-15', difficulty: '⭐⭐⭐', score: 92 },
    { title: '首次接触技巧', date: '2023-10-12', difficulty: '⭐⭐', score: 85 },
    { title: '投诉处理模拟', date: '2023-10-08', difficulty: '⭐⭐⭐', score: 88 },
    { title: '长期合作谈判', date: '2023-10-02', difficulty: '⭐⭐⭐⭐', score: 78 }
  ];

  motivationalPhrases = [
    "每一次对话都是展现专业的机会，每一次练习都在提升成功的概率！今天，让AI成为您最强大的销售伙伴",
    "每一次拒绝都是离成功更近一步！",
    "卓越的销售不是推销产品，而是解决问题！",
    "今天的练习，明天的签约！",
    "客户的需求是您成功的地图，AI是您的导航仪！",
    "专业来自准备，成功源于坚持！",
    "您不是一个人在战斗，AI是您最强大的后援！"
  ];

  ngOnInit(): void {
    // 随机选择激励语句
    this.updateMotivationalText();
    
    // 每10秒更新一次激励语句
    setInterval(() => this.updateMotivationalText(), 10000);
    
    // 每5秒更新统计数据
    setInterval(() => this.updateStats(), 5000);
  }

  updateMotivationalText(): void {
    const randomIndex = Math.floor(Math.random() * this.motivationalPhrases.length);
    this.motivationalText = this.motivationalPhrases[randomIndex];
  }

  updateStats(): void {
    // 模拟数据更新
    this.stats.practiceCount = Math.floor(Math.random() * 20 + 35);
    this.stats.strategyCount = Math.floor(Math.random() * 15 + 20);
    this.stats.satisfactionRate = Math.floor(Math.random() * 5 + 94);
  }

  toggleMessagePopup(): void {
    this.showMessagePopup = !this.showMessagePopup;
    if (this.showMessagePopup) {
      // 标记消息为已读
      this.unreadMessagesCount = 0;
      this.messages.forEach(msg => msg.unread = false);
    }
  }

  toggleProfilePopup(): void {
    this.showProfilePopup = !this.showProfilePopup;
  }

  closeMessagePopup(event?: MouseEvent): void {
    if (event && event.target !== event.currentTarget) return;
    this.showMessagePopup = false;
  }

  closeProfilePopup(event?: MouseEvent): void {
    if (event && event.target !== event.currentTarget) return;
    this.showProfilePopup = false;
  }

  navigateTo(feature: string): void {
    console.log(`Navigating to ${feature}`);
    // 实际项目中这里会有路由导航逻辑
    // this.router.navigate([`/${feature}`]);
  }
}