import { Component } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { MatIconModule } from '@angular/material/icon';
import { MatButtonModule } from '@angular/material/button';
import { MatCardModule } from '@angular/material/card';
import { MatProgressSpinnerModule } from '@angular/material/progress-spinner';
import { FontAwesomeModule } from '@fortawesome/angular-fontawesome';
import { faMicrophone, faSquare, faArrowLeft, faLayerGroup, faEdit, faPlus, faTimes, faChartLine, faFileAlt, faHistory, faArrowUp, faComments, faStar, faLightbulb } from '@fortawesome/free-solid-svg-icons';

@Component({
  selector: 'app-page-crm-training',
  standalone: true,
  imports: [
    CommonModule,
    FormsModule,
    MatIconModule,
    MatButtonModule,
    MatCardModule,
    MatProgressSpinnerModule,
    FontAwesomeModule,
   
  ],
   templateUrl:'./page-crm-training.html',
  styleUrls: ['./page-crm-training.scss']
})
export class PageCrmTraining {
  // Font Awesome 图标
  faMicrophone = faMicrophone;
  faSquare = faSquare;
  faArrowLeft = faArrowLeft;
  faLayerGroup = faLayerGroup;
  faEdit = faEdit;
  faPlus = faPlus;
  faTimes = faTimes;
  faChartLine = faChartLine;
  faFileAlt = faFileAlt;
  faHistory = faHistory;
  faArrowUp = faArrowUp;
  faComments = faComments;
  faStar = faStar;
  faLightbulb = faLightbulb;

  // 组件状态和逻辑
  isVoiceActive = false;
  selectedDifficulty = '初级';
  difficulties = [
    { label: '⭐ 初级', value: '初级' },
    { label: '⭐⭐ 中级', value: '中级' },
    { label: '⭐⭐⭐ 高级', value: '高级' },
    { label: '专家挑战', value: '专家' }
  ];
  
  customerTypes = [
    { name: '商务客户', active: true },
    { name: '家庭客户', active: false },
    { name: 'VIP客户', active: false },
    { name: '投诉客户', active: false },
    { name: '团体客户', active: false }
  ];
  isEditingTypes = false;
  newCustomerType = '';
  
  messages = [
    { text: '您好，我想预订下周五的商务套房，你们有什么优惠吗？', isCustomer: true },
    { text: '感谢您的咨询！我们目前有商务套餐优惠，包含早餐和会议室使用，您需要了解详情吗？', isCustomer: false },
    { text: '会议室可以容纳多少人？另外我需要延迟退房到下午4点。', isCustomer: true },
    { text: '我们的商务套房会议室最多可容纳20人，延迟退房到下午4点需要额外支付50%的房费。', isCustomer: false },
    { text: '50%的费用太高了，我是贵酒店的黄金会员，能否提供免费延迟退房？', isCustomer: true },
    { text: '感谢您的会员支持！根据黄金会员权益，我们可以提供免费延迟退房到下午2点，或者您可以选择支付额外费用延长到4点。', isCustomer: false },
    { text: '下午2点可能不太够，我下午3点有个重要会议。有没有折中方案？', isCustomer: true },
    { text: '我理解您的情况。我们可以为您提供下午3点的延迟退房，只需额外支付25%的房费，这样您看可以接受吗？', isCustomer: false }
  ];
  newMessage = '';
  
  skills = [
    { name: '反应力', value: 90 },
    { name: '话术', value: 85 },
    { name: '说服力', value: 75 },
    { name: '专业度', value: 92 }
  ];
  
  showAddCustomerModal = false;
  showFullReportModal = false;
  showHistoryReportModal = false;
  
  historyReports = [
    { 
      id: 1,
      date: '2023年10月15日 14:30',
      type: '商务客户',
      summary: '本次与商务客户的对话中，您展现了优秀的专业知识和反应能力。建议在价格谈判环节采用更积极的策略。'
    },
    { 
      id: 2,
      date: '2023年10月12日 10:15',
      type: '投诉客户',
      summary: '处理客户投诉时展现了良好的同理心，但解决方案不够全面，建议加强问题解决能力训练。'
    },
    { 
      id: 3,
      date: '2023年10月10日 16:45',
      type: 'VIP客户',
      summary: '为VIP客户提供了个性化服务方案，展现了出色的服务意识，但在附加服务推荐上略显保守。'
    }
  ];

  toggleVoice() {
    this.isVoiceActive = !this.isVoiceActive;
  }
  
  selectDifficulty(difficulty: string) {
    this.selectedDifficulty = difficulty;
  }
  
  selectCustomerType(index: number) {
    if (!this.isEditingTypes) {
      this.customerTypes.forEach(type => type.active = false);
      this.customerTypes[index].active = true;
    }
  }
  
  deleteCustomerType(index: number) {
    if (this.customerTypes.length > 1) {
      this.customerTypes.splice(index, 1);
    } else {
      alert('至少需要保留一个客户类型');
    }
  }
  
  addCustomerType() {
    if (this.newCustomerType.trim()) {
      this.customerTypes.push({ name: this.newCustomerType.trim(), active: false });
      this.newCustomerType = '';
      this.showAddCustomerModal = false;
    }
  }
  
  sendMessage() {
    if (this.newMessage.trim()) {
      this.messages.push({ text: this.newMessage, isCustomer: false });
      this.newMessage = '';
      
      // 模拟AI回复
      setTimeout(() => {
        this.messages.push({ 
          text: "听起来不错，我会考虑这个方案。能提供一份详细报价吗？", 
          isCustomer: true 
        });
      }, 1000);
    }
  }
  
  getCircleDashOffset() {
    const circumference = 2 * Math.PI * 80;
    const progress = 86; // 86%
    return circumference - (progress / 100) * circumference;
  }
}